<?php

namespace SM\Service;

use SM\Factory\CdaFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CdaService
{

    protected $CdaFactory;
    protected $Environment;
    protected $newCode;


    public function __construct(EntityManager $entityManager, CdaFactory $CdaFactory, Environment $Environment, NewCode $newCode)
    {
        $this->CdaFactory = $CdaFactory;
        $this->connection                   = $entityManager->getConnection();
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function getCda($params)
    {
        $dataParams = array(
            "CDFUNC"            => $params["CDFUNC"],
            "CDFILIAL"          => $params["CDFILIAL"],
            "CDEMPRESA"         => $params["CDEMPRESA"],
            "NRORG"             => $params["NRORG"],
            "CDOPERADOR"        => $params["CDOPERADOR"],
            "DTINICIALPERIODO"  => $params["DTINICIALPERIODO"],
            "DTFINALPERIODO"    => $params["DTFINALPERIODO"],
        );
        return $this->CdaFactory->getCda($dataParams);
    }

    public function getFuncionarios()
    {
        return $this->CdaFactory->getFuncionarios();
    }

    public function getFuncionarioLogado()
    {
        $cdoperador = $this->Environment->getCdOperador();
        return $cdoperador;
    }

    public function getPeriodoApuraPonto()
    {
        return $this->CdaFactory->getPeriodoApuraPonto();
    }

    public function salvarTipoLocalAtendimento($parametros)
    {
        $cdoperador = $this->Environment->getCdOperador();
        $NRORG = $this->Environment->getNrOrg();
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $classification) {
                if ($classification["NRTIPOESTRUTURA"] == 0) {
                    $NRTIPOESTRUTURA = $this->newCode->getCodeByTableName("TIPOESTRUTURA", $NRORG, 1, 10, true);
                    $dataParam = array(
                        "NRTIPOESTRUTURA" => $NRTIPOESTRUTURA,
                        "NMTIPOESTRUTURA"   => $classification["NMTIPOESTRUTURA"],
                        "NRORG"              => $NRORG,
                        "NRORGINCLUSAO"      => $NRORG,
                        "CDOPERINCLUSAO"     => $cdoperador,
                        "IDATIVO"            => "S",

                    );
                    $this->CdaFactory->salvarTipoLocalAtendimento($dataParam);
                } else {
                    $dataParam = array(
                        "NRTIPOESTRUTURA" => $classification["NRTIPOESTRUTURA"],
                        "NMTIPOESTRUTURA"  => $classification["NMTIPOESTRUTURA"],
                        "CDOPERULTATU"      => $cdoperador,
                        "NRORGULTATU"       => $NRORG,
                    );
                    $this->CdaFactory->atualizarTipoLocalAtendimento($dataParam);
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletarTipoLocalAtendimento($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $classification) {
                $dataParam = array("NRTIPOESTRUTURA" => $classification["NRTIPOESTRUTURA"],);
                $this->CdaFactory->deletarTipoLocalAtendimento($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
