import { Utilities } from '@/util/Utilities';
import {
    LoadingService, ModalService, Select,
} from '@zeedhi/common';
import { Http, IDictionary, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { ZdTabs } from '@zeedhi/vuetify';

export class FilterCdaController {
    private campofilter: any;
    
    private funcionarioLogado: any;

    public currentRow: any = {};

    public eventFilter({ event }: any) {
        event.preventDefault();
        this.abrirModalFilter();
    }

    public async abrirModalFilter() {
        await this.exibirModalFilter();
    }

    public async exibirModalFilter() {
        this.campofilter = await ModalService.createFromJson('sm_cda/Modal/sm_cda_filter_modal', true);
        this.campofilter.show();
    }

    public fecharModalFilter() {
        this.campofilter.hide();
        this.campofilter?.destroy();
    }

    public async insereFuncionarioLogado() {
        LoadingService.show();
        Http.get('/getFuncionarioLogado').then((response: IDictionary) => {
            this.funcionarioLogado = response.data;
            Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').value = this.funcionarioLogado;
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public async insereUltimoPeriodo() {
        LoadingService.show();
        Http.get('/getPeriodoApuraPonto').then((response: IDictionary) => {
            Metadata.getInstance<Select>('formFilterCda-PERIODOAPURAPONTO').value = response.data.data[0].DISPLAY;
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public filterGrid({ row }: any) {
        this.currentRow = row;

        const grid = Metadata.getInstance<TekGrid>('cda-tek-grid');
        const nmoperador = Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').datasource.data[0].NMOPERADOR;
        const cdoperador = Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').datasource.data[0].CDOPERADOR;
        const cdfunc = Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').datasource.data[0].CDFUNC;
        const cdempresa = Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').datasource.data[0].CDEMPRESA;
        const cdfilial = Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').datasource.data[0].CDFILIAL;
        const nrorg = Metadata.getInstance<Select>('formFilterCda-NMOPERADOR').datasource.data[0].NRORG;
        const dtinicialperiodo = Metadata.getInstance<Select>('formFilterCda-PERIODOAPURAPONTO').datasource.data[0].VALUE.substr(0, 10);
        const dtfinalperiodo = Metadata.getInstance<Select>('formFilterCda-PERIODOAPURAPONTO').datasource.data[0].VALUE.substr(11);
        const statusPeriodo = Metadata.getInstance<Select>('formFilterCda-PERIODOAPURAPONTO').datasource.data[0].STATUS;

        grid.datasource.setFilter({
            NMOPERADOR: nmoperador,
            CDOPERADOR: cdoperador,
            CDFUNC: cdfunc,
            CDEMPRESA: cdempresa,
            CDFILIAL: (cdfilial === null) ? 'null' : cdfilial,
            NRORG: nrorg,
            DTINICIALPERIODO: dtinicialperiodo,
            DTFINALPERIODO: dtfinalperiodo,
        });
        
        Metadata.getInstance<ZdTabs>('tabFuncionario-cda-SM').tabs[0].tabTitle = `${nmoperador} - ${dtinicialperiodo} até ${dtfinalperiodo} ${statusPeriodo}`;
        this.fecharModalFilter();
    }
}
